@@ -5,7 +5,7 @@ use strict;
 use base 'DBIx::Class::Schema';
 use File::HomeDir;
 
-our $VERSION = '0.001007'; # 0.1.7
+our $VERSION = '0.001008'; # 0.1.8
 $VERSION = eval $VERSION;
 
 sub connection {
@@ -48,30 +48,50 @@ sub load_credentials {
     # independently unit tested.
     return $connect_args if $connect_args->{dsn} =~ /^dbi:/i; 
 
-    my $ConfigAny = Config::Any->load_stems( 
-        { stems => $class->config_paths, use_ext => 1 } 
+    # If we have ->config_files, we'll use those and load_files
+    # instead of the default load_stems.
+    my %cf_opts = ( use_ext => 1 );
+    my $ConfigAny = @{$class->config_files}
+        ? Config::Any->load_files({ files => $class->config_files, %cf_opts })
+        : Config::Any->load_stems({ stems => $class->config_paths, %cf_opts });
+
+    return $class->filter_loaded_credentials(
+        $class->_find_credentials( $connect_args, $ConfigAny ),
+        $connect_args
     );
 
+}
+
+# This will look through the data structure returned by Config::Any
+# and return the first instance of the database credentials it can
+# find.
+sub _find_credentials {
+    my ( $class, $connect_args, $ConfigAny ) = @_;
+    
     for my $cfile ( @$ConfigAny ) {
         for my $filename ( keys %$cfile ) {
             for my $database ( keys %{$cfile->{$filename}} ) {
                 if ( $database eq $connect_args->{dsn} ) {
-                    my $loaded_credentials = $cfile->{$filename}->{$database};
-                    return $class->filter_loaded_credentials(
-                        $loaded_credentials,$connect_args
-                    );
+                    return $cfile->{$filename}->{$database};
                 }
             }
         }
     }
 }
 
+sub get_env_vars {
+    return $ENV{DBIX_CONFIG_DIR} . "/dbic" if exists $ENV{DBIX_CONFIG_DIR};
+    return ();
+}
+
 # Intended to be sub-classed, we'll just return the
 # credentials we used in the first place.
 sub filter_loaded_credentials { $_[1] };
 
 __PACKAGE__->mk_classaccessor('config_paths'); 
-__PACKAGE__->config_paths([('./dbic', File::HomeDir->my_home . '/.dbic', '/etc/dbic')]);
+__PACKAGE__->mk_classaccessor('config_files'); 
+__PACKAGE__->config_paths([( get_env_vars(), './dbic', File::HomeDir->my_home . '/.dbic', '/etc/dbic')]);
+__PACKAGE__->config_files([  ] );
 
 1;
 
@@ -120,6 +140,12 @@ This module will load the files in the following order if they exist:
 
 =over 4
 
+=item * C<$ENV{DBIX_CONFIG_DIR}> . '/dbic', 
+
+C<$ENV{DBIX_CONFIG_DIR}> can be configured at run-time, for instance:
+
+    DBIX_CONFIG_DIR="/var/local/" ./my_program.pl
+
 =item * ./dbic.*
 
 =item * ~/.dbic.*
@@ -152,6 +178,27 @@ The above code would have I</var/www/secret/dbic.*> and I</opt/database.*>
 searched, in that order.  As above, the first credentials found would be used.  
 This will replace the files origionally searched for, not add to them.
 
+=head1 USE SPECIFIC CONFIG FILES
+
+If you would rather explicitly state the configuration files you
+want loaded, you can use the class accessor C<config_files>
+instead.
+
+    package My::Schema
+    use warnings;
+    use strict;
+
+    use base 'DBIx::Class::Schema::Config';
+    __PACKAGE__->config_files([( '/var/www/secret/dbic.yaml', '/opt/database.yaml' )]);
+
+This will check the files, C</var/www/secret/dbic.yaml>, 
+and C</opt/database.yaml> in the same way as C<config_paths>, 
+however it will only check the specific files, instead of checking 
+for each extension that L<Config::Any> supports.  You MUST use the 
+extension that corresponds to the file type you are loading.  
+See L<Config::Any> for information on supported file types and 
+extension mapping.
+
 =head1 OVERRIDING
 
 The API has been designed to be simple to override if you have additional 
@@ -274,7 +321,7 @@ The function should return the same structure.  For instance:
 
 =head1 AUTHOR
 
-SymKat I<E<lt>symkat@symkat.comE<gt>>
+Kaitlyn Parkhurst (SymKat) I<E<lt>symkat@symkat.comE<gt>> ( Blog: L<http://symkat.com/> )
 
 =head1 CONTRIBUTORS
 
